@@ -12,14 +12,18 @@ class JSONGeneratorEncoder(DjangoJSONEncoder):
 
 
 class JSONExporter(BaseExporter):
+    short_name = 'JSON'
+    long_name = 'JavaScript Object Notation (JSON)'
+
     file_extension = 'json'
     content_type = 'application/json'
-    preferred_formats = ('number', 'string')
 
-    def write(self, iterable, buff=None):
+    preferred_formats = ('json', 'number', 'string')
+
+    def write(self, iterable, buff=None, *args, **kwargs):
         buff = self.get_file_obj(buff)
 
         encoder = JSONGeneratorEncoder()
-        for chunk in encoder.iterencode(self.read(iterable)):
+        for chunk in encoder.iterencode(self.read(iterable, *args, **kwargs)):
             buff.write(chunk)
         return buff
